tiled.queries.NotIn
===================

.. currentmodule:: tiled.queries

.. autoclass:: NotIn

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~NotIn.__init__
      ~NotIn.decode
      ~NotIn.encode
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~NotIn.key
      ~NotIn.value
   
   